@@ -99,12 +99,12 @@ impl OpenFortiVpn {
         netns.dns_config(dns_ip.as_slice(), suffixes.as_slice())?;
         // Allow input to and output from open ports (for port forwarding in tunnel)
         if let Some(opens) = open_ports {
-            super::util::open_ports(&netns, opens.as_slice(), firewall)?;
+            super::util::open_ports(netns, opens.as_slice(), firewall)?;
         }
 
         // Allow input to and output from forwarded ports
         if let Some(forwards) = forward_ports {
-            super::util::open_ports(&netns, forwards.as_slice(), firewall)?;
+            super::util::open_ports(netns, forwards.as_slice(), firewall)?;
         }
 
         Ok(Self { pid: id })
